@@ -67,6 +67,9 @@
 #define CACHE_SELF_CHECKS 0
 
 #define ICON_NAME_THUMBNAIL_LOADING     "gnome-fs-loading-icon"
+#define ICON_NAME_TRASH_EMPTY		"gnome-fs-trash-empty"
+#define ICON_NAME_TRASH_FULL		"gnome-fs-trash-full"
+
 #define NAUTILUS_EMBLEM_NAME_PREFIX "emblem-"
 
 /* This used to be called ICON_CACHE_MAX_ENTRIES, but it's misleading
@@ -702,6 +705,14 @@ nautilus_icon_factory_get_icon_for_file (NautilusFile *file)
  	g_free (custom_uri);
 
 	file_uri = nautilus_file_get_uri (file);
+	
+	if (strcmp (file_uri, EEL_TRASH_URI) == 0) {
+		g_free (file_uri);
+
+		return  g_strdup (nautilus_trash_monitor_is_empty ()
+				  ? ICON_NAME_TRASH_EMPTY : ICON_NAME_TRASH_FULL);
+	}
+	
 	mime_type = nautilus_file_get_mime_type (file);
 	
 	file_info = nautilus_file_peek_vfs_file_info (file);
@@ -1431,6 +1442,29 @@ nautilus_icon_factory_get_thumbnail_frame (void)
 	return get_icon_factory ()->thumbnail_frame;
 }
 
+gboolean
+nautilus_icon_factory_remove_from_cache (const char *icon_name,
+					 const char *modifier,
+					 const char *embedded_text,
+					 guint size)
+{
+	GHashTable *hash_table;
+	NautilusIconFactory *factory;
+	CacheKey lookup_key;
+
+	factory = get_icon_factory ();
+	hash_table = factory->icon_cache;
+
+	/* Check to see if it's already in the table. */
+	lookup_key.name = (char *)icon_name;
+	lookup_key.modifier = (char *)modifier;
+	lookup_key.embedded_text = (char *)embedded_text;
+	lookup_key.nominal_size = size;
+	
+	return g_hash_table_remove (hash_table, &lookup_key);
+}
+					 
+
 static gboolean
 embedded_text_rect_usable (GnomeIconData *icon_data)
 {
