@@ -211,6 +211,9 @@ struct NautilusIconContainerDetails {
 	
 	/* Is the container fixed or resizable */
 	gboolean is_fixed_size;
+	
+	/* Is the container for a desktop window */
+	gboolean is_desktop;
 
 	/* Ignore the visible area the next time the scroll region is recomputed */
 	gboolean reset_scroll_region_trigger;
