@@ -54,6 +54,7 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbox.h>
+#include <libegg/egg-screen-help.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-macros.h>
 #include <libgnomeui/gnome-dialog.h>
@@ -68,7 +69,6 @@
 #include <libnautilus-private/nautilus-link.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-undo-signal-handlers.h>
-#include <libnautilus-private/egg-screen-help.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-view-identifier.h>
 #include <libnautilus/nautilus-undo.h>
@@ -635,7 +635,7 @@ clear_bonobo_pages (FMPropertiesWindow *window)
 
 	num_pages = gtk_notebook_get_n_pages
 				(GTK_NOTEBOOK (window->details->notebook));
-				 
+
 	for (i=0; i <  num_pages; i++) {
 		page = gtk_notebook_get_nth_page
 				(GTK_NOTEBOOK (window->details->notebook), i);
@@ -643,6 +643,8 @@ clear_bonobo_pages (FMPropertiesWindow *window)
 		if (g_object_get_data (G_OBJECT (page), "is-bonobo-page")) {
 			gtk_notebook_remove_page
 				(GTK_NOTEBOOK (window->details->notebook), i);
+			num_pages--;
+			i--;
 		}
 	}
 }
@@ -677,7 +679,7 @@ properties_window_file_changed_callback (FMPropertiesWindow *window, NautilusFil
 		new_mime_type = nautilus_file_get_mime_type
 						(window->details->target_file);
 
-		if (strcmp (orig_mime_type, new_mime_type) == 0) {
+		if (strcmp (orig_mime_type, new_mime_type) != 0) {
 			refresh_bonobo_pages (window);
 		}
 
@@ -2206,22 +2208,31 @@ bonobo_page_activate_callback (CORBA_Object obj,
 
 	if (obj != CORBA_OBJECT_NIL) {
 		Bonobo_Control control;
-		Nautilus_View view;
+		Bonobo_PropertyBag pb;
+		BonoboArg *arg;
 		char *uri;
 		
+		uri = nautilus_file_get_uri (window->details->target_file);
+
 		control = Bonobo_Unknown_queryInterface
 				(obj, "IDL:Bonobo/Control:1.0", &ev);
 
-		view = Bonobo_Unknown_queryInterface
-				(control, "IDL:Nautilus/View:1.0", &ev);
 
-		uri = nautilus_file_get_uri (window->details->target_file);
+		pb = Bonobo_Control_getProperties (control, &ev);
 
-		Nautilus_View_load_location (view, uri, &ev);
-		
 		if (!BONOBO_EX (&ev)) {
-			widget = bonobo_widget_new_control_from_objref
-						(control, CORBA_OBJECT_NIL);
+			arg = bonobo_arg_new (BONOBO_ARG_STRING);
+			BONOBO_ARG_SET_STRING (arg, uri);
+
+			bonobo_pbclient_set_value_async (pb, "URI", arg, &ev);
+			bonobo_arg_release (arg);
+			bonobo_object_release_unref (pb, NULL);
+
+			if (!BONOBO_EX (&ev)) {
+				widget = bonobo_widget_new_control_from_objref
+							(control, CORBA_OBJECT_NIL);
+				bonobo_object_release_unref (control, &ev);
+			}
 		}
 
 		g_free (uri);
@@ -2245,10 +2256,9 @@ append_bonobo_pages (FMPropertiesWindow *window)
 	GList *components, *l;
 	CORBA_Environment ev;
 
-	/* find all the property page views for this file */
-	components = nautilus_mime_get_all_components_for_file_extended
-		(window->details->target_file,
-		 "nautilus:property_page_name.defined()");
+	/* find all the property pages for this file */
+	components = nautilus_mime_get_property_components_for_file
+					(window->details->target_file);
 	
 	CORBA_exception_init (&ev);
 
@@ -2339,9 +2349,9 @@ help_button_callback (GtkWidget *widget, GtkWidget *property_window)
 	GError *error = NULL;
 	char *message;
 
-	egg_screen_help_display_desktop (
-		gtk_window_get_screen (GTK_WINDOW (property_window)),
-		NULL, "user-guide", "wgosnautilus.xml", "gosnautilus-51", &error);
+	egg_help_display_desktop_on_screen (NULL, "user-guide", "wgosnautilus.xml", "gosnautilus-51",
+					    gtk_window_get_screen (GTK_WINDOW (property_window)),
+&error);
 
 	if (error) {
 		message = g_strdup_printf (_("There was an error displaying help: \n%s"),
